@@ -1,6 +1,7 @@
 #coding:utf-8
 
 import os
+import shutil
 import fnmatch
 
 def all_file(root, patterns='*.pyc', ignore_dirs=[], \
@@ -19,6 +20,11 @@ def all_file(root, patterns='*.pyc', ignore_dirs=[], \
                 subdirs.remove(d)
         for pattern in patterns:
             fs = fnmatch.filter(files, pattern)
+            ds = fnmatch.filter(subdirs, pattern)
+            if ds:
+                for d in ds:
+                    subdirs.remove(d)
+                fs = fs + ds
             if not fs:
                 if no_matchs: log('no match files in %s' % path, logger)
                 continue
@@ -43,7 +49,11 @@ def clean(args, logger=None, no_matchs=False):
             no_matchs=no_matchs):
         log(f, logger)
         try:
-            os.remove(os.path.realpath(f))
+            path = os.path.realpath(f)
+            if not os.path.isdir(path):
+                os.remove(path)
+            else:
+                shutil.rmtree(path)
         except Exception, e:
             pass
 
